# Analysis of data from the control experiment of ALEXIS 120 (constant stimuli, no feedback)
# This script uses MCMC to draw samples from posterior distribution for each individudal. 
# It takes time!
#
# MN 2020-09-16


## Clear everything ------------------------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
## ----------------------------------------------------------------------------


## Load stuff ------------------------------------------------------------------
library(rstan) 

# Load MCMC data, one object per participant
load("analys/mcmc_main.RData")

# Load functions
source("analys/1_a120_functions.R") 
## -----------------------------------------------------------------------------


## Read raw data ---------------------------------------------------------------
d <- read.table("./rawdata/rawdata_a120_control.txt", sep = ",", header = TRUE,
                stringsAsFactors = FALSE)
d$llr <- ifelse(d$llr > 6, 6, d$llr)  # Fix max value
head(d)
table(d$id, d$task)
table(d$id, d$day)
## -----------------------------------------------------------------------------


## Get and save samples from the posterior  ------------------------------------

# Compile model 
stanmodel <- stan_model(file = "./analys/control.stan")

# Function that fits model for one participant
sample_posterior <- function(id) {
  g <- d[d$id == id, ]
  dat <- list(
    N <- nrow(g),
    x <- g$llr,
    y <- g$pc,
    z <- g$task) 
  
  
  model <- sampling(stanmodel, data = dat, chains = 1, iter = 1e4, warmup = 5e3)
  print(model)
  
  draws <- extract(model)
  draws
} 

# Get samples from the posterior for each participant (this takes time!)
ids <- sort(unique(d$id))

for (j in ids) {
  draws <- sample_posterior(j)  # Draw samples from posterior
  nam <- paste("controldraws_id", j, sep = "") # Name of object with draws
  assign(nam, draws)  # Save as object with name nam
  print(sprintf("ID %d now done", j)) 
}

# Save all objects named draws_* to file mcmc_data.RData
save(list = ls(pattern = glob2rx('controldraws_*')), file = "analys/mcmc_control.RData")
## -----------------------------------------------------------------------------

