# Analysis of data from experiment ALEXIS 120
# MCMC analysis of pilot experiment with three participnats, mathcing ILD to ITD = 0.25,
# using constant stimuli method.
# MN 2019-10-01


## Clear everything ------------------------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
## ----------------------------------------------------------------------------

library(rstan)
library(rethinking)


## Read data -------------------------------------------------------------------
d <- read.table("./rawdata/rawdata_a120_itdild.txt", sep = ",", header = TRUE)

d$itd_left <- 1 * (as.integer(d$itd_location) == 1)

head(d)
table(d$id, d$day)
## -----------------------------------------------------------------------------



## Get and save draws from posterior -------------------------------------------

# Compile model 
stanmodel <- stan_model(file = "./analys/itdild.stan")

get_draws <- function(id) {
  g <- d[d$id == id, ]
  N <- nrow(g)
  x <- g$ild
  y <- g$itd_left
  z <- 1 * (g$side < 0)
  
  model <- sampling(stanmodel, data = list(N = N, x = x, y = y),
                chains = 1, iter = 1e4, warmup = 2e3)
  print(model)
  draws <- extract(model)
  draws
}

ildmatch001 <- get_draws(120001)
ildmatch002 <- get_draws(120002)
ildmatch999 <- get_draws(120999)

save(ildmatch001, ildmatch002, ildmatch999, file = "analys/mcmc_itdild.RData")
## -----------------------------------------------------------------------------
