# Analysis of data from experiment ALEXIS 120: Post-test after training
# This script uses MCMC to draw samples from posterior distribution for each individudal. 
# It takes time!
#
# MN 2020-09-16


## Clear everything ------------------------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
## ----------------------------------------------------------------------------

library(rstan)


## Read data -------------------------------------------------------------------
d <- read.table("./rawdata/rawdata_a120_post.txt", sep = ",", header = TRUE,
                stringsAsFactors = FALSE)
head(d)
d$cond <- d$ici + 1000 * d$task
table(d$id, d$task)
table(d$id, d$day)
## -----------------------------------------------------------------------------


## Get and save samples from the posterior  ------------------------------------
# Compile model 
stanmodel <- stan_model(file = "./analys/main.stan")

# Function that fits model for one participant
sample_posterior <- function(id) {
  g <- d[d$id == id, ]
  dat <- list(
    N = nrow(g),
    N_cond = length(unique(g$cond)),
    N_task = length(unique(g$task)),
    x = g$llr,
    cond = as.integer(factor(g$cond)),
    task = as.integer(factor(g$task)),
    y = g$pc) 

  model <- sampling(stanmodel, data = dat, chains = 1, iter = 1e4, warmup = 5e3)
  print(model)
  
  draws <- extract(model)
  draws
} 


# Get samples from the posterior for each participant (this takes time!)
ids <- sort(unique(d$id))

for (j in ids) {
  draws <- sample_posterior(j)  # Draw samples from posterior
  nam <- paste("postdraws_id", j, sep = "") # Name of object with draws
  assign(nam, draws)  # Save as object with name nam
  print(sprintf("ID %d now done", j))
}

# Save all objects named draws_* to file mcmc_data.RData
save(list = ls(pattern = glob2rx('postdraws_*')), file = "analys/mcmc_post.RData")
## -----------------------------------------------------------------------------
