# Experiment ALEXIS 120
# Functions for loading data and plotting results. 
#
# MN 2019-04-16

library(HDInterval)  # hdi()

## Prepare plotting  -----------------------------------------------------------
subplot <- function(rr, cc, nr, nc, xmar = 0, ymar = 0){
  # Defines position of subplot
  # Arguments:
  # rr -- row of subplot
  # cc -- column of subplot
  # nr -- number of rows of subplots
  # nc -- number of columns of subplots
  # xmar -- margin for things below figures, e.g., xaxis text (proportion of 1)
  # ymar -- margin for things to the left of figures, e.g., yaxis text (proportion of 1)
  # Output:
  # out -- four number vector to be used in par(fig = out)
  
  x <- seq(0 + ymar, 1, length.out = nc + 1)
  y <- seq(1, 0 + xmar, length.out = nr + 1)
  xout <- c(x[cc], x[cc+1])
  yout <- c(y[rr + 1], y[rr])
  out <- c(xout, yout)
  out
}
## -----------------------------------------------------------------------------


## Plot single staircase ------------------------------------------------------
stairplot <- function(id = 120001, day = 1, session = 1, ymin = -80) {
  xlim = c(0, 53)
  ylim = c(ymin, 10)
  g <- d[d$id == id & d$day == day & d$session == session, ]
  plot(g$trial, g$llr, pch = '', ylim = ylim, 
       xlab = '', ylab = '', axes = FALSE)
  lines(g$trial, g$llr)
  points(g$trial, g$llr, pch = 21, bg = 'grey', cex = 0.7)
  #points(g$trial[g$reversal == 1], g$llr[g$reversal == 1], pch = 21, bg = 'red')
  
  # Add axis
  xticks <- seq(xlim[1], xlim[2], by = 1)
  xlabels <- c('', xticks[2:length(xticks)])
  #xlabels <- rep('', length(xticks))
  #xlabels[seq(1, 52, by = 10) + 1] = seq(1, 52, by = 10)
  axis(1, at = xticks, labels = xlabels,
       tck = 0.01, pos = ylim[1], cex.axis = 0.5, mgp = c(3, -0.2, 0))
  axis(3, at = xticks, labels = FALSE, tck = 0.01, pos = ylim[2])
  
  axis(2, at = c(ylim[1], seq(ylim[1] + 5, ylim[2] - 5, by = 5), ylim[2]), 
       labels = c('', seq(ylim[1] + 5, ylim[2] - 5, by = 5), ''),
       las = 2, tck = 0.01, pos = xlim[1], cex.axis = 0.5, mgp = c(3, 0.4, 0))
  axis(4, at = c(ylim[1], seq(ylim[1] + 5, ylim[2] - 5, by = 5), ylim[2]),
       labels = FALSE, las = 2, tck = 0.01, pos = xlim[2])
}
## -----------------------------------------------------------------------------


## Plot data and psychometric function for one id and condition (task x ici)
plot_condition <- function(id = 120001, task = 0, ici = 12, addpsychom = TRUE) {
  # Plot data from one id and condition (task x ici)
  
  g <- d[d$id == id & d$task == task & d$ici == ici, ]
  nrow(g)
  gg <- aggregate(list(y = g$pc), list(x = g$llr), mean)
  gg$n <- aggregate(list(y = g$pc), list(x = g$llr), length)[, 2]
  
  # Plot data
  xlim = c(-75, 10)
  ylim = c(-0.05, 1.05)
  plot(0, 0.5, pch = '', xlim = xlim, ylim = ylim,
       xlab = '', ylab = '', axes = FALSE)
  lines(xlim, c(0.5, 0.5), lty = 3)
  lines(xlim, c(0, 0), lty = 1, col = 'grey')
  lines(xlim, c(1, 1), lty = 1, col = 'grey')
  points(gg$x, gg$y, cex = 0.5*gg$n**0.5, pch = 21, bg = 'white')
  
  # Add axis
  axis(1, at = c(xlim[1], seq(xlim[1]+5, xlim[2]-5, by = 5), xlim[2]), 
       labels = c('', seq(xlim[1]+5, xlim[2]-5, by = 5), ''),
       tck = 0.01, pos = ylim[1], cex.axis = 0.5, mgp = c(3, -0.2, 0))
  axis(3, at = c(xlim[1], seq(xlim[1]+5, xlim[2]-5, by = 5), xlim[2]), labels = FALSE,
       tck = 0.01, pos = ylim[2])
  
  axis(2, at = c(ylim[1], seq(ylim[1] + 0.05, ylim[2]  - 0.05, by = 0.1), ylim[2]), 
       labels =  c('', seq(ylim[1] + 0.05, ylim[2]  - 0.05, by = 0.1), ''),
       las = 2, tck = 0.01, pos = xlim[1], cex.axis = 0.5, mgp = c(3, 0.4, 0))
  axis(4, at = c(ylim[1], seq(ylim[1] + 0.05, ylim[2]  - 0.05, by = 0.1), ylim[2]), labels = FALSE,
       las = 2, tck = 0.01, pos = xlim[2])
  
  if (addpsychom) {
    add_psychometric(id = id, task = task, ici = ici)
  }
  
}

add_psychometric <- function(id = 120001, task = 0, ici = 12){
  # Add psychometric function(s) to plot_condition(), by sampling from
  # posterior. Global variables with draws have to be loaded
  
  # Load global variable with samples from individual posterior
  fname <- ls(envir=.GlobalEnv, pattern = paste('maindraws_id', id, sep = ''))
  print(fname)  # Just as a check
  draws <- get(fname)
  
  # Find column of draws object with task x ici condition
  icis <- which( ici == c(6, 8.5, 12, 17, 24, 34, 48, 200))
  cc <- (task * 8) + icis  # Column of draws with samples for condition
  
  # Add samples, transparent lines
  rand_funct <- function(row){
    row <- sample(1:8e3, size = 1)
    m <- draws$m[row, cc]
    w <- draws$w[row, cc]
    lambda <- draws$lambda[row]
    x <- seq(-75, 10, by = 0.1)
    y <- 0.5 + (0.5 - lambda)*pnorm((x-m)/w)
    lines(x, y, col = rgb(0.2, 1, 0.2, 0.05))
  }
  
  replicate(1e2, rand_funct())
  
  # Add 'median' function
  m <- median(draws$m[, cc])
  w <- median(draws$w[, cc])
  lambda <- median(draws$lambda)
  x <- seq(-75, 10, by = 0.1)
  y <- 0.5 + (0.5 - lambda)*pnorm((x-m)/w)
  lines(x, y, col = 'darkgreen', lwd = 1.5)
}
## -----------------------------------------------------------------------------

## Function to generate thresholds ---------------------------------------------
th <- function(id) {
  # Load global variable with samples from individual posterior
  fname <- ls(envir=.GlobalEnv, pattern = paste('maindraws_id', id, sep = ''))
  print(fname)  # Just as a check
  draws <- get(fname)
  
  # Threshold: parameter m
  th <- apply(draws$m, 2, median)
  thci <- apply(draws$m, 2, hdi)
  out <- rbind(th, thci)
  colnames(out) <- c('det6', 'det8.5', 'det12', 'det17', 'det24', 'det34', 'det48', 'det200',
                     'lat6', 'lat8.5', 'lat12', 'lat17', 'lat24', 'lat34', 'lat48', 'lat200')
  sstat <- c('mdn', 'hdpi95lo', 'hdpi95hi')
  ss <- rep(id, nrow(out))
  out <- data.frame(id = ss, stat = sstat, out)
  rownames(out) <- c()  # Get rid of row names
  out # Output is a data frame
}
## -----------------------------------------------------------------------------


## Function to generate threshold differences ----------------------------------
# Difference: th_lateralization - th_detection 
th_diff <- function(id) {
  # Load global variable with samples from individual posterior
  fname <- ls(envir=.GlobalEnv, pattern = paste('maindraws_id', id, sep = ''))
  print(fname)  # Just as a check
  draws <- get(fname)
  
  # Threshold: parameter m
  diff <- apply((draws$m[, 9:16] - draws$m[, 1:8]),
                  2, median)
  
  diffci <- apply((draws$m[, 9:16] - draws$m[, 1:8]),
                    2, hdi)
  out <- rbind(diff, diffci)
  colnames(out) <- c('ici6', 'ici8.5', 'ici12', 'ici17', 'ici24', 'ici34', 'ici48', 'ici200')
  sstat <- c('mdn', 'hdpi95lo', 'hdpi95hi')
  ss <- rep(id, nrow(out))
  out <- data.frame(id = ss, stat = sstat, out)
  rownames(out) <- c()  # Get rid of row names
  out
}
## -----------------------------------------------------------------------------



## Threshold plot --------------------------------------------------------------
indplot_th <- function(id, xlabels = TRUE, ylabels = TRUE, cex.axis = 0.4, axislwd = 0.4) {
  dd <- th(id)  # Data frame with thresholds
  # Remove 2 first cols to make life easier: detect, cols 1:8; lat, cols 9:16
  dd <- dd[, 3:ncol(dd)]  
  ici <- as.numeric(gsub("[[:alpha:]]", "", colnames(dd)))  # Take ici from column names
  ici[ici == 200] <- 61  # Move 200 closer
  ici <- log2(ici)
  
  # Make exmpty plot
  xlim <- c(2.3, 6.1)
  ylim <- c(-65, 5)
  plot(ici[1:8], rep(0, 8), pch = '', xlim = xlim, ylim = ylim,  
       xlab = '', ylab = '', axes = FALSE)
  
  j <- 0.02 # CI horizontal jitter
  
  lwd <- 0.6  # Thickness of symbols, ci, ad lines
  
  
  # Add detection
  x <- ici[1:8]
  y <- as.numeric(dd[1, 1:8])
  ylo <- as.numeric(dd[2, 1:8])
  yhi <- as.numeric(dd[3, 1:8])
  lines(x[1:7], y[1:7], lty = 1, lwd = lwd, col = 'grey')  
  lines(c(xlim[1], xlim[2]), c(y[8], y[8]), lty = 2, col = 'grey', lwd = lwd)  # Baseline condition
  arrows(x0 = x+j, x1 = x+j, y0 = ylo,  y1 = yhi,
         angle = 90, code = 3, length = 0.0, lwd = lwd)
  points(x, y, pch = 21, cex = 0.8, bg = 'grey', lwd = lwd)
  
  # Add laterlization
  x <- ici[1:8]
  y <- as.numeric(dd[1, 9:16])
  ylo <- as.numeric(dd[2, 9:16])
  yhi <- as.numeric(dd[3, 9:16])
  lines(x[1:7], y[1:7], lty = 1, lwd = lwd, col = 'grey')  
  lines(c(xlim[1], xlim[2]), c(y[8], y[8]), lty = 3, col = 'black', lwd = lwd)  # Baseline condition
  arrows(x0 = x-j, x1 = x-j, y0 = ylo,  y1 = yhi,
         angle = 90, code = 3, length = 0.0, lwd = lwd)
  points(x, y, pch = 22, cex = 0.7, bg = rgb(1, 1, 1), lwd = lwd)
  
  # Add axis
  xlabs = c('', round(2**ici[1:7]), '', '')
  xlabs = c('', 6, '', 12, '', 24, '', 48, '', '')
  if (!xlabels ) {xlabs = FALSE}
  
  ylabs = c('', seq(ylim[1]+5, ylim[2]-5, by = 10), '')
  if (!ylabels ) {ylabs = FALSE}
  
  axis(1, at = c(xlim[1], ici[1:8], xlim[2]), labels = xlabs, 
       tck = 0.01, pos = ylim[1], cex.axis = cex.axis, mgp = c(3, 0, 0), lwd = axislwd)
  axis(3, at = c(xlim[1], ici[1:8], xlim[2]), labels = FALSE, 
       tck = 0.01, pos = ylim[2], lwd = axislwd)
  
  axis(2, at = c(ylim[1], seq(ylim[1]+5, ylim[2]-5, by = 10), ylim[2]), 
       labels = ylabs,
       las = 2, tck = 0.01, pos = xlim[1], cex.axis = cex.axis, mgp = c(3, 0.4, 0), lwd = axislwd)
  axis(4, at = c(ylim[1], seq(ylim[1]+5, ylim[2]-5, by = 10), ylim[2]), labels = FALSE,
       las = 2, tck = 0.01, pos = xlim[2], lwd = axislwd)
  
  # Break x-axis
  lines(c(log2(55), log2(55)), c(ylim[1]-1, ylim[1]+1), col = 'white', lwd = 8)  # Lower
  lines(c(log2(55), log2(55)), c(ylim[2]-1, ylim[2]+1), col = 'white', lwd = 8)  # upper
  
  # Add id number
  idtext <- sprintf("ID: %d", id - 120000)
  text(log2(9), 0, idtext, cex = 0.4, font = 3)
  }

# indplot_th(120011, xlabels = TRUE, ylabels = FALSE)
## -----------------------------------------------------------------------------



## Functions to draw individual thresholds in the same plot (group plot) -------

# Empty plot to which individual data will be added
empty_group <- function(ylabels = TRUE, cex.axis = 0.5, axislwd = 0.4) {
  id <- 120001 # get a data frame just to get ICIs
  dd <- th(id) 
  
  # Remove 2 first cols to make life easier: detect, cols 1:8; lat, cols 9:16
  dd <- dd[, 3:ncol(dd)]  
  ici <- as.numeric(gsub("[[:alpha:]]", "", colnames(dd)))  # Take ici from column names
  ici[ici == 200] <- 61  # Move 200 closer
  ici <- log2(ici)
  
  # Make exmpty plot
  xlim <- c(2.3, 6.1)
  ylim <- c(-59, 1)
  plot(ici[1:8], rep(0, 8), pch = '', xlim = xlim, ylim = ylim,  
       xlab = '', ylab = '', axes = FALSE)

  # Add axis
  xlabs = c('', round(2**ici[1:7]), '', '')

  ylabs = c('', seq(ylim[1]+4, ylim[2]-1, by = 10), '')
  if (!ylabels ) {ylabs = FALSE}
  
  axis(1, at = c(xlim[1], ici[1:8], xlim[2]), labels = xlabs, 
       tck = 0.01, pos = ylim[1], cex.axis = cex.axis, mgp = c(3, 0, 0), lwd = axislwd)
  axis(3, at = c(xlim[1], ici[1:8], xlim[2]), labels = FALSE, 
       tck = 0.01, pos = ylim[2], lwd = axislwd)
  
  axis(2, at = c(ylim[1], seq(ylim[1]+4, ylim[2]-1, by = 10), ylim[2]), 
       labels = ylabs, las = 2, tck = 0.01, pos = xlim[1], 
       cex.axis = cex.axis, mgp = c(3, 0.4, 0), lwd = axislwd)
  axis(4, at = c(ylim[1], seq(ylim[1]+4, ylim[2]-1, by = 10), ylim[2]), labels = FALSE,
       las = 2, tck = 0.01, pos = xlim[2], lwd = axislwd)
  
  # Break x-axis
  lines(c(log2(55), log2(55)), c(ylim[1]-1, ylim[1]+1), col = 'white', lwd = 8)  # Lower
  lines(c(log2(55), log2(55)), c(ylim[2]-1, ylim[2]+1), col = 'white', lwd = 8)  # upper

}


add_ind <- function(id, detect = TRUE, ci = TRUE, pch = 21, bg = 'grey', cex = 0.7) {
  dd <- th(id)  # Data frame with thresholds 
  # Remove 2 first cols to make life easier: detect, cols 1:8; lat, cols 9:16
  dd <- dd[, 3:ncol(dd)]  
  ici <- as.numeric(gsub("[[:alpha:]]", "", colnames(dd)))  # Take ici from column names
  ici[ici == 200] <- 61  # Move 200 closer
  ici <- log2(ici)
  
  if (detect) {
    # Add detection
    x <- ici[1:8]
    y <- as.numeric(dd[1, 1:8])
    ylo <- as.numeric(dd[2, 1:8])
    yhi <- as.numeric(dd[3, 1:8])
    lines(x[-8], y[-8], lty = 1, col = 'grey')  # ICI conditions
    
    if (ci) {
      arrows(x0 = x, x1 = x, y0 = ylo,  y1 = yhi,
             angle = 90, code = 3, length = 0.0, col = rgb(0.2, 0.2, 0.2))
    }
    
    points(x, y, pch = pch, bg = bg, cex = cex)
    
  } else {
    # Add laterlization
    x <- ici[9:16]
    y <- as.numeric(dd[1, 9:16])
    ylo <- as.numeric(dd[2, 9:16])
    yhi <- as.numeric(dd[3, 9:16])
    lines(x[-8], y[-8], lty = 1, col = 'grey')  # ICI conditions
    if (ci) {
      arrows(x0 = x, x1 = x, y0 = ylo,  y1 = yhi,
             angle = 90, code = 3, length = 0.0, col = rgb(0.2, 0.2, 0.2))
    }
    points(x, y, pch = pch, bg = bg, cex = cex)
  }
}


# Empty plot to which individual th-differences will be added
empty_diff <- function(ylabels = TRUE, cex.axis = 0.5, axislwd = 0.4) {
  id <- 120001 # get a data frame just to get ICIs
  dd <- th(id) 
  
  # Remove 2 first cols to make life easier: detect, cols 1:8; lat, cols 9:16
  dd <- dd[, 3:ncol(dd)]  
  ici <- as.numeric(gsub("[[:alpha:]]", "", colnames(dd)))  # Take ici from column names
  ici[ici == 200] <- 61  # Move 200 closer
  ici <- log2(ici)
  
  # Make exmpty plot
  xlim <- c(2.3, 6.1)
  ylim <- c(-6, -6+60)
  plot(ici[1:8], rep(0, 8), pch = '', xlim = xlim, ylim = ylim,  
       xlab = '', ylab = '', axes = FALSE)
  
  # Add no-effect region
  polygon(x = c(xlim, rev(xlim)), y = c(3, 3, -3, -3), density = 200, col = rgb(0.8, 0.8, 0.8, 0.2))
  
  # Add axis
  xlabs = c('', round(2**ici[1:7]), '', '')
  
  ylabs = c('', seq(ylim[1]+1, ylim[2]-1, by = 5), '')
  if (!ylabels ) {ylabs = FALSE}
  
  axis(1, at = c(xlim[1], ici[1:8], xlim[2]), labels = xlabs, 
       tck = 0.01, pos = ylim[1], cex.axis = cex.axis, mgp = c(3, 0, 0), lwd = axislwd)
  axis(3, at = c(xlim[1], ici[1:8], xlim[2]), labels = FALSE, 
       tck = 0.01, pos = ylim[2], lwd = axislwd)
  
  axis(2, at = c(ylim[1], seq(ylim[1]+1, ylim[2]-1, by = 5), ylim[2]), 
       labels = ylabs,
       las = 2, tck = 0.01, pos = xlim[1], cex.axis = cex.axis, 
       , lwd = axislwd, mgp = c(3, 0.4, 0))
  axis(4, at = c(ylim[1], seq(ylim[1]+1, ylim[2]-1, by = 5), ylim[2]), labels = FALSE,
       las = 2, tck = 0.01, pos = xlim[2], lwd = axislwd)
  
  # Break x-axis
  lines(c(log2(55), log2(55)), c(ylim[1]-1, ylim[1]+1), col = 'white', lwd = 8)  # Lower
  lines(c(log2(55), log2(55)), c(ylim[2]-1, ylim[2]+1), col = 'white', lwd = 8)  # upper
  
}


add_inddiff <- function(id, ci = TRUE, pch = 21, bg = 'grey', cex = 0.7) {
  dd <- th_diff(id)  # Data frame with threshold
  # Remove 2 first cols to make life easier: detect, cols 1:8; lat, cols 9:16
  dd <- dd[, 3:ncol(dd)]  
  ici <- as.numeric(gsub("[[:alpha:]]", "", colnames(dd)))  # Take ici from column names
  ici[ici == 200] <- 61  # Move 200 closer
  ici <- log2(ici)
  
  x <- ici
  y <- as.numeric(dd[1, ])
  ylo <- as.numeric(dd[2, ])
  yhi <- as.numeric(dd[3, ])
  lines(x[-8], y[-8], lty = 1, col = 'grey')  # ICI conditions
  
  if (ci) {
    arrows(x0 = x, x1 = x, y0 = ylo,  y1 = yhi,
           angle = 90, code = 3, length = 0.00, col = rgb(0.2, 0.2, 0.2))
  }
  
  points(x, y, pch = pch, bg = bg, cex = cex)
  
}
## -----------------------------------------------------------------------------


