# Alexis 120. Figure with data from main experiment grouped per task
# MN 2020-10-01


## Clear everything ------------------------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
## ----------------------------------------------------------------------------


## Loadstuff -------------------------------------------------------------------
library(HDInterval)  # hdi()

source("analys/1_a120_functions.R") 
source("analys/2_a120_set_variables.R") 

# Load MCMC data main
load("analys/mcmc_main.RData")
## -----------------------------------------------------------------------------


## Plotting function -----------------------------------------------------------
add_legend <- function(id, pch, bg = 'white', xloc = 6, yloc, cex = 0.6) {
  points(x = log2(xloc), y = yloc, pch = pch, bg = bg, cex = cex)
  idtext <- sprintf("%d", id - 120000)
  text(x = log2(xloc-0.6), y = yloc, idtext, cex = 0.4, font = 1, pos = 4)
}
## -----------------------------------------------------------------------------


## Define saving option for plot -----------------------------------------------
savefig = figsave # 0 = dont save, show in Rstudio, 1 = pdf, 2 = png

# Open pdf (paper = 'letter' or 'A4' to get fig on full page)
if(savefig == 1) {
  pdf("./manus/fig3.pdf", width = 15/2.54, height = 7/2.54, paper = 'letter')
}

# Open png 
if(savefig == 2) {
  png("./manus/fig3.png", units = "in", res = 600, width = 15/2.54, height = 7/2.54)
}
## -----------------------------------------------------------------------------


## Plot ------------------------------------------------------------------------
plot.new()
par(mar = c(0, 0, 0, 0), oma = c(0, 0, 0, 0), lwd = 0.4)
nr <- 1
nc <- 3
xmar <- 0.1
ymar <- 0.1
idorder <- gaporder


# Left panel (detection) -------------------------------------------------------
par(mar = c(0, 2, 0, 0))
par(fig = subplot(rr = 1, cc = 1, xmar = xmar, ymar = ymar, nr = nr, nc = nc), new = TRUE)
empty_group()
add_ind(idorder[1], pch = 21, detect = TRUE, ci = FALSE, bg = 'white')
add_ind(idorder[2], pch = 21, detect = TRUE, ci = FALSE, bg = 'grey')
add_ind(idorder[3], pch = 22, detect = TRUE, ci = FALSE, bg = 'white')
add_ind(idorder[4], pch = 22, detect = TRUE, ci = FALSE, bg = 'grey')
add_ind(idorder[5], pch = 23, detect = TRUE, ci = FALSE, bg = 'white')
add_ind(idorder[6], pch = 23, detect = TRUE, ci = FALSE, bg = 'grey')
add_ind(idorder[7], pch = 24, detect = TRUE, ci = FALSE, bg = 'white')
add_ind(idorder[8], pch = 24, detect = TRUE, ci = FALSE, bg = 'grey')
add_ind(idorder[9], pch = 25, detect = TRUE, ci = FALSE, bg = 'white')
add_ind(idorder[10], pch = 25, detect = TRUE, ci = FALSE, bg = 'grey')

add_ind(idorder[11], pch = 21, detect = TRUE, ci = FALSE, bg = 'white')
add_ind(idorder[11], pch = 20, detect = TRUE, ci = FALSE, cex = 0.2)  # Add dot
add_ind(idorder[12], pch = 21, detect = TRUE, ci = FALSE, bg = 'grey')
add_ind(idorder[12], pch = 20, detect = TRUE, ci = FALSE, cex = 0.2)  # Add dot
add_ind(idorder[13], pch = 22, detect = TRUE, ci = FALSE, bg = 'white')
add_ind(idorder[13], pch = 20, detect = TRUE, ci = FALSE, cex = 0.2)  # Add dot

text(log2(48), -2, "Detection", pos = 2, cex = 0.6, font = 3)

# Legend (left panel)
b <- -1  # y-axis start of legend
g <- 0.5 # x-position second column oflegend
text(x = log2(6), y = b, "ID", cex = 0.4, font = 1, pos = 4)
add_legend(idorder[1], pch = 21, bg = 'white', xloc = 6, yloc = -2 + b)
add_legend(idorder[2], pch = 21, bg = 'grey', xloc = 6, yloc = -4 + b)
add_legend(idorder[3], pch = 22, bg = 'white', xloc = 6, yloc = -6 + b)
add_legend(idorder[4], pch = 22, bg = 'grey', xloc = 6, yloc = -8 + b)
add_legend(idorder[5], pch = 23, bg = 'white', xloc = 6, yloc = -10 + b)
add_legend(idorder[6], pch = 23, bg = 'grey', xloc = 6, yloc = -12 + b)
add_legend(idorder[7], pch = 24, bg = 'white', xloc = 6, yloc = -14 + b)
add_legend(idorder[8], pch = 24, bg = 'grey', xloc = 9 + g, yloc = -2 + b)
add_legend(idorder[9], pch = 25, bg = 'white', xloc = 9 + g, yloc = -4 + b)
add_legend(idorder[10], pch = 25, bg = 'grey', xloc = 9 + g, yloc = -6 + b)

add_legend(idorder[11], pch = 21, bg = 'white', xloc = 9 + g, yloc = -8 + b)
add_legend(idorder[11], pch = 20, cex = 0.2, xloc = 9 + g, yloc = -8 + b) # Add dot
add_legend(idorder[12], pch = 21,  bg = 'grey', xloc = 9 + g, yloc = -10 + b)
add_legend(idorder[12], pch = 20, cex = 0.2, xloc = 9 + g, yloc = -10 + b) # Add dot
add_legend(idorder[13], pch = 22,  bg = 'white', xloc = 9 + g, yloc = -12 + b)
add_legend(idorder[13], pch = 20, cex = 0.2, xloc = 9 + g, yloc = -12 + b) # Add dot
# ------------------------------------------------------------------------------

# Middle panel (lateralization) ------------------------------------------------
par(mar = c(0, 0, 0, 2))
par(fig = subplot(rr = 1, cc = 2, xmar = xmar, ymar = ymar, nr = nr, nc = nc), new = TRUE)
empty_group(ylabels = FALSE)
add_ind(idorder[1], pch = 21, detect = FALSE, ci = FALSE, bg = 'white')
add_ind(idorder[2], pch = 21, detect = FALSE, ci = FALSE, bg = 'grey')
add_ind(idorder[3], pch = 22, detect = FALSE, ci = FALSE, bg = 'white')
add_ind(idorder[4], pch = 22, detect = FALSE, ci = FALSE, bg = 'grey')
add_ind(idorder[5], pch = 23, detect = FALSE, ci = FALSE, bg = 'white')
add_ind(idorder[6], pch = 23, detect = FALSE, ci = FALSE, bg = 'grey')
add_ind(idorder[7], pch = 24, detect = FALSE, ci = FALSE, bg = 'white')
add_ind(idorder[8], pch = 24, detect = FALSE, ci = FALSE, bg = 'grey')
add_ind(idorder[9], pch = 25, detect = FALSE, ci = FALSE, bg = 'white')
add_ind(idorder[10], pch = 25,  detect = FALSE, ci = FALSE,  bg = 'grey')

add_ind(idorder[11], pch = 21, detect = FALSE, ci = FALSE, bg = 'white')
add_ind(idorder[11], pch = 20, detect = FALSE, ci = FALSE,cex = 0.2)  # Add dot
add_ind(idorder[12], pch = 21, detect = FALSE, ci = FALSE, bg = 'grey')
add_ind(idorder[12], pch = 20, detect = FALSE, ci = FALSE, cex = 0.2)  # Add dot
add_ind(idorder[13], pch = 22, detect = FALSE, ci = FALSE, bg = 'white')
add_ind(idorder[13], pch = 20, detect = FALSE, ci = FALSE, cex = 0.2)  # Add dot

text(log2(48), -2, "Lateralization", pos = 2, cex = 0.6, font = 3)

# ------------------------------------------------------------------------------

# Right panel (detect - lateralization) ----------------------------------------
par(fig = subplot(rr = 1, cc = 3, xmar = xmar, ymar = ymar, nr = nr, nc = nc), new = TRUE)
empty_diff()
add_inddiff(idorder[1], pch = 21, ci = FALSE, bg = 'white')
add_inddiff(idorder[2], pch = 21, ci = FALSE, bg = 'grey')
add_inddiff(idorder[3], pch = 22, ci = FALSE, bg = 'white')
add_inddiff(idorder[4], pch = 22, ci = FALSE, bg = 'grey')
add_inddiff(idorder[5], pch = 23, ci = FALSE, bg = 'white')
add_inddiff(idorder[6], pch = 23, ci = FALSE, bg = 'grey')
add_inddiff(idorder[7], pch = 24, ci = FALSE, bg = 'white')
add_inddiff(idorder[8], pch = 24, ci = FALSE, bg = 'grey')
add_inddiff(idorder[9], pch = 25, ci = FALSE, bg = 'white')
add_inddiff(idorder[10], pch = 25, ci = FALSE, bg = 'grey')

add_inddiff(idorder[11], pch = 21, ci = FALSE, bg = 'white')
add_inddiff(idorder[11], pch = 20, ci = FALSE, cex = 0.2)  # Add dot
add_inddiff(idorder[12], pch = 21, ci = FALSE, bg = 'grey')
add_inddiff(idorder[12], pch = 20, ci = FALSE, cex = 0.2)  # Add dot
add_inddiff(idorder[13], pch = 22, ci = FALSE, bg = 'white')
add_inddiff(idorder[13], pch = 20, ci = FALSE, cex = 0.2)  # Add dot

text(log2(66), 51, "Lateralization - Detection", pos = 2, cex = 0.6, font = 3)

# ------------------------------------------------------------------------------

# Add axis texts (A lot of trial and error to get right values of argument line)
cex = 0.75
par(fig = c(0, 1, 0, 1), new = TRUE)
# Empty plot 0-100, so you know the scale of mtext()-argument at 
plot(0:100, 0:100, pch = '', xlab = '', ylab = '', axes = FALSE) 

mtext("Threshold [dB]", 
      cex = cex, side = 2, line = -3.5, at = 55)
mtext("Threshold difference (lateralization - detection), [dB]", 
      cex = cex - 0.15, side = 2, line = -19.7, at = 55)
mtext("Inter-click interval, ICI [ms]", 
      cex = cex, side = 1, line = -1.0, at = 55)

# Add ICI = 200 ms
arrows(x0 = 40.2,      x1 = 40.2, y0 = 34.5, y1 = 44, length = 0.05, angle = 30, code = 1,
       lwd = 0.5)
text("ICI = 200 ms", x = 40.5,      y = 50, cex = 0.5, pos = 3, srt = 90)
## -----------------------------------------------------------------------------


## Close pdf or png ------------------------------------------------------------
if(savefig > 0){
  graphics.off() 
}
## -----------------------------------------------------------------------------

