# Alexis 120. Plot with individual data main experiment
#
# MN2020-10-01


## Clear everything ------------------------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
## -----------------------------------------------------------------------------


## Load stuff ------------------------------------------------------------------
source("analys/2_a120_set_variables.R")  # This also load functions
load("analys/mcmc_main.RData")
## -----------------------------------------------------------------------------


## Define saving option for plot -----------------------------------------------
savefig = figsave # 0 = dont save, show in Rstudio, 1 = pdf, 2 = png

# Open pdf (paper = 'letter' or 'A4' to get fig on full page)
if(savefig == 1) {
  pdf("./manus/fig2.pdf", width = 16/2.54, height = 16/2.54, paper = 'letter')
}

# Open png 
if(savefig == 2) {
  png("./manus/fig2.png", units = "in", res = 600, width = 15/2.54, height = 15/2.54)
}
## -----------------------------------------------------------------------------

## Plotting function -----------------------------------------------------------
plotid <- function(id, rr = 1, cc = 1, nr = 4, nc = 3, ymar = 0.1, xmar = 0.1, 
               xtext = NULL, xlabels = FALSE, ytext = NULL, ylabels = FALSE) {
  
  par(fig = subplot(rr = rr, cc = cc, nr = nr, nc = nc, xmar = xmar, ymar = ymar), 
      new = TRUE)
  indplot_th(id, xlabels = xlabels, ylabels = ylabels)

  mtext(text = xtext, side = 1, line = 0.5, cex = 0.9)
  mtext(text = ytext, side = 2, line = 1, cex = 0.9)
}
## -----------------------------------------------------------------------------


## Plot ------------------------------------------------------------------------
plot.new()
par(mar = c(0, 0, 0, 0), oma = c(0, 0, 0, 0))
xtext <- "Inter-click interval [ms]"
ytext <- "Lag-lead ratio [dB]"
nr <- 3
nc <- 5
ymar <- 0.03 
xmar <- 0.06

idorder <- gaporder  # See file 2_a120_load_data.R for gaporder definition

# Row 1 ----
plotid(idorder[1], rr = 1, cc = 1, nr = nr, nc = nc, ylabels = TRUE)
plotid(idorder[2], rr = 1, cc = 2, nr = nr, nc = nc)
plotid(idorder[3], rr = 1, cc = 3, nr = nr, nc = nc)
plotid(idorder[4], rr = 1, cc = 4, nr = nr, nc = nc)
plotid(idorder[5], rr = 1, cc = 5, nr = nr, nc = nc)

# Row 2 ----
plotid(idorder[6], rr = 2, cc = 1, nr = nr, nc = nc, ylabels = TRUE)
plotid(idorder[7], rr = 2, cc = 2, nr = nr, nc = nc)
plotid(idorder[8], rr = 2, cc = 3, nr = nr, nc = nc)
plotid(idorder[9], rr = 2, cc = 4, nr = nr, nc = nc, xlabels = TRUE)
plotid(idorder[10], rr = 2, cc = 5, nr = nr, nc = nc, xlabels = TRUE)

# Row 4 ----
plotid(idorder[11], rr = 3, cc = 1, nr = nr, nc = nc, xlabels = TRUE, ylabels = TRUE)
plotid(idorder[12], rr = 3, cc = 2, nr = nr, nc = nc, xlabels = TRUE)
plotid(idorder[13], rr = 3, cc = 3, nr = nr, nc = nc, xlabels = TRUE)



# Add axis texts (A lot of trial and error to get right values of argument line)
cex = 0.8
par(fig = c(0, 1, 0, 1), new = TRUE)
# Empty plot 0-100, so you know the scale of mtext()-argument at 
plot(0:100, 0:100, pch = '', xlab = '', ylab = '', axes = FALSE) 

mtext("Threshold [dB]", 
      cex = cex, side = 2, line = -1.8, at = 55)
mtext("Inter-click interval, ICI [ms]", 
      cex = cex, side = 1, line = -2.5, at = 55)

# Add ICI = 200 ms
arrows(x0 = 63.2,      x1 = 63.2, y0 = 14.5, y1 = 17, length = 0.05, angle = 30, code = 1,
       lwd = 0.5)
text("ICI = 200 ms", x = 63.6,      y = 20, cex = 0.5, pos = 3, srt = 90)

# Add legend
lcex = 0.6
points(               x = 68, y = 33, pch = 22, bg = 'white', lwd = 0.4)
text("Lateralization threshold", x = 68.7, y = 33, cex = lcex, pos = 4)

points(           x = 68, y = 31, pch = 21, bg = 'grey', lwd = 0.4)
text("Detection threshold", x = 68.7, y = 31, cex = lcex, pos = 4)

lines(            x = c(68, 68), y = c(27, 25), lwd = 0.4)
text("95% compatibility interval", x = 68.7,        y = 26, cex = lcex, pos = 4)

lines(            x = c(67, 69), y = c(23, 23), lwd = 0.65, lty = 3, col = 'black')
text("Lateralization threshold baseline (ICI = 200 ms)", x = 68.7,  y = 23, cex = lcex, pos = 4)

lines(            x = c(67, 69), y = c(21, 21), lwd = 0.65, lty = 2, col = 'grey')
text("Detection threshold baseline (ICI = 200 ms)", x = 68.7, y = 21, cex = lcex, pos = 4)
## -----------------------------------------------------------------------------


## Close pdf or png ------------------------------------------------------------
if(savefig > 0){
  graphics.off() 
}
## -----------------------------------------------------------------------------
