# ALEXIS 120. Figure training: pre- vs. post test. (The 30 day training data in 
# separate figure, not included in this figure).
#
# MN 2020-10-01

## Clear everything ------------------------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
## -----------------------------------------------------------------------------


## Load stuff ------------------------------------------------------------------
library(HDInterval) # HPDI()

# Load user/made functions
source("analys/1_a120_functions.R")
source("analys/2_a120_set_variables.R")

# Load MCMC pre-test = main experiment and pos-post
load("analys/mcmc_main.RData")
load("analys/mcmc_post.RData")
## -----------------------------------------------------------------------------


## Functions for plotting pre and post data ------------------------------------
empty_prepost <- function(xlabels = TRUE, ylabels = TRUE, ylim = c(-65, 5),
                          cex.axis = 0.5, axislwd = 0.4, shade0db = FALSE) {
  
  # Define x-axis values (geomteric series of ICIs in log2 units)
  ici <- log2(c(6, sqrt(6*12), 12, sqrt(12*24), 24, sqrt(24*48), 48, sqrt(48*96)))
  
  # Make empty plot
  xlim <- c(2.3, 6.1)
  ylim <- ylim
  plot(ici[1:8], rep(0, 8), pch = '', xlim = xlim, ylim = ylim,  
       xlab = '', ylab = '', axes = FALSE)
  
  # Shade +/- 3 dB around zero: no-effect region if differecne plot
  if(shade0db) {
    polygon(x = c(xlim, rev(xlim)), y = c(3, 3, -3, -3), density = 200, col = rgb(0.8, 0.8, 0.8, 0.2))
  }
    
  # Add axis
  xlabs = c('', round(2**ici[1:7]), '', '')
  if (!xlabels ) {xlabs = FALSE}
  
  ylabs = c('', seq(ylim[1]+5, ylim[2]-5, by = 10), '')
  if (!ylabels ) {ylabs = FALSE}
  
  axis(1, at = c(xlim[1], ici[1:8], xlim[2]), labels = xlabs, 
       tck = 0.01, pos = ylim[1], cex.axis = cex.axis, mgp = c(3, 0, 0),
       lwd = axislwd)
  axis(3, at = c(xlim[1], ici[1:8], xlim[2]), labels = FALSE, 
       tck = 0.01, pos = ylim[2], lwd = axislwd)
  
  axis(2, at = c(ylim[1], seq(ylim[1]+5, ylim[2]-5, by = 10), ylim[2]), 
       labels = ylabs, las = 2, tck = 0.01, pos = xlim[1], 
       lwd = axislwd, cex.axis = cex.axis, mgp = c(3, 0.4, 0))
  axis(4, at = c(ylim[1], seq(ylim[1]+5, ylim[2]-5, by = 10), ylim[2]), labels = FALSE,
       las = 2, tck = 0.01, pos = xlim[2], lwd = axislwd)
  
  # Break x-axis
  lines(c(log2(55), log2(55)), c(ylim[1]-1, ylim[1]+1), col = 'white', lwd = 8)  # Lower
  lines(c(log2(55), log2(55)), c(ylim[2]-1, ylim[2]+1), col = 'white', lwd = 8)  # upper
  

  }

add_prepost <- function(id, wave = 0, task = 0, j = 0, 
                        pch = 21, bg = 'white', lty = 1, 
                        lwd = 0.6, linecol = 'grey', xlim = c(2.3, 6.1),
                        symbollwd = 0.5) {
  # j is displacement of CI-bars, 0 is at point
  
  # Load global variable with samples from individual posterior
  id <- id + 120000
  
  if (wave == 0) {
    fname <- ls(envir=.GlobalEnv, pattern = paste('maindraws_id', id, sep = ''))
    print(fname)  # Just as a check
    d <- get(fname)
  } else {
    fname <- ls(envir=.GlobalEnv, pattern = paste('postdraws_id', id, sep = ''))
    print(fname)  # Just as a check
    d <- get(fname)
  }

  m <- apply(d$m, 2, median)
  mlo <- apply(d$m, 2, hdi)[1, ]
  mhi <- apply(d$m, 2, hdi)[2, ]

  if (task == 0)  {# Detection
    m <- m[1:8]
    mlo <- mlo[1:8]
    mhi <- mhi[1:8]
    baselty = 2

  }  else { # Laterlization
    m <- m[9:16]
    mlo <- mlo[9:16]
    mhi <- mhi[9:16]
    baselty = 3

  }
  
  # X-values
  ici <- log2(c(6, sqrt(6*12), 12, sqrt(12*24), 24, sqrt(24*48), 48, sqrt(48*96)))
  ici[8] <- log2(61)  # Move baseline to point ici = 57
  
  # Data points
  arrows(x0 = ici+j, x1 = ici+j, y0 = mlo, y1 = mhi, 
         length = 0.0, angle = 90, code = 3, lwd = lwd, col = linecol)
  lines(ici[-8], m[1:7], lty = lty, lwd = lwd, col = linecol)
  lines(xlim, c(m[8], m[8]), lty = baselty, lwd = lwd, col = linecol) # Baseline
  points(ici, m, pch = pch, bg = bg, lwd = symbollwd)
}


add_gapsize <- function(id, wave = 0, j = 0, xlim = c(2.3, 6.1),
                            pch = 21, bg = 'white', lty = 1, 
                            lwd = 0.6, linecol = 'grey',
                            symbollwd = 0.5) {
  
  # Load global variable with samples from individual posterior
  id <- id + 120000
  
  if (wave == 0) {
    fname <- ls(envir=.GlobalEnv, pattern = paste('maindraws_id', id, sep = ''))
    print(fname)  # Just as a check
    d <- get(fname)
  } else {
    fname <- ls(envir=.GlobalEnv, pattern = paste('postdraws_id', id, sep = ''))
    print(fname)  # Just as a check
    d <- get(fname)
  }
  

  m <- apply(d$m[, 9:16] - d$m[, 1:8], 2, median)
  mlo <- apply(d$m[, 9:16] - d$m[, 1:8], 2, hdi)[1, ]
  mhi <- apply(d$m[, 9:16] - d$m[, 1:8], 2, hdi)[2, ]


  # X-values
  ici <- log2(c(6, sqrt(6*12), 12, sqrt(12*24), 24, sqrt(24*48), 48, sqrt(48*96)))
  ici[8] <- log2(61)  # Move baseline to point ici = 57
  
  # Data points
  arrows(x0 = ici+j, x1 = ici+j, y0 = mlo, y1 = mhi, 
         length = 0.0, angle = 90, code = 3, lwd = lwd, col = linecol)
  lines(ici[-8], m[1:7], lwd = lwd, col = linecol)
  points(ici, m, pch = pch, bg = bg, lwd = symbollwd, cex = 0.7)
}


idplot <- function(id, rr, xlabels = FALSE, legend = FALSE){
  # Lefthand panel, pre-test
  par(fig = subplot(rr = rr, cc = 1, nr = nr, nc = nc, xmar = xmar, ymar = ymar),
      mar = mar1, new = (rr != 1))  # new = FALSE for first plot: rr = 1, cc = 1
  empty_prepost(ylim = ylim, xlabels = xlabels)
  add_prepost(id = id, wave = 0, task = 0, j = -j, bg = 'grey')
  add_prepost(id = id, wave = 0, task = 1, j = j, pch = 22, bg = 'white')
  
  idtext <- sprintf("ID: %d", id)  # Add id number
  text(log2(7), 0, idtext, cex = 0.6, font = 3)
  
  # Middle panel. post-test
  par(fig = subplot(rr = rr, cc = 2, nr = nr, nc = nc, xmar = xmar, ymar = ymar), 
      mar = mar2, new = TRUE)
  empty_prepost(ylim = ylim, xlabels = xlabels, ylabels = FALSE)
  add_prepost(id = id, wave = 1, task = 0, j = -j, bg = 'grey')
  add_prepost(id = id, wave = 1, task = 1, j = j, pch = 22, bg = 'white')
  
  if (legend) {
    points(log2(6), -0, pch = 22, bg = 'white', cex = 0.6, lwd = 0.5)
    text(log2(6), -0, "Lateralization threshold", pos = 4, cex = 0.5)
    points(log2(6), -4, pch = 21, bg = 'grey', cex = 0.6, lwd = 0.5)
    text(log2(6), -4, "Detection threshold", pos = 4, cex = 0.5)
  }
  
  # Right panel, Diff plot
  par(fig = subplot(rr = rr, cc = 3, nr = nr, nc = nc, xmar = xmar, ymar = ymar), 
      mar = mar3, new = TRUE)
  empty_prepost(ylim = c(-10, 60), xlabels = xlabels, shade0db = TRUE)
  lines(c(2.3, 6.1), c(0, 0), lty = 3, col = 'black') # No diff
  add_gapsize(id = id, wave = 0, j = -j, pch = 24, bg = 'lightgrey')
  add_gapsize(id = id, wave = 1, j = j,  pch = 25, bg = 'darkgrey')
  
  if (legend) {
    points(log2(6), 55, pch = 24, bg = 'lightgrey', cex = 0.5, lwd = 0.5)
    text(log2(6), 55, "Pre-test threshold diff.", pos = 4, cex = 0.5)
    points(log2(6), 51, pch = 25, bg = 'darkgrey', cex = 0.5, lwd = 0.5)
    text(log2(6), 51, "Post-test threshold diff.", pos = 4, cex = 0.5)
  }
}
## -----------------------------------------------------------------------------

## Define saving option for plot -----------------------------------------------
savefig = figsave # 0 = dont save, show in Rstudio, 1 = pdf, 2 = png

# Open pdf (paper = 'letter' or 'A4' to get fig on full page)
if(savefig == 1) {
  pdf("./manus/fig5.pdf", width = 15/2.54, height = 20/2.54, paper = 'letter')
}

# Open png 
if(savefig == 2) {
  png("./manus/fig5.png", units = "in", res = 600, width = 15/2.54, height = 16/2.54)
}
## -----------------------------------------------------------------------------


## Plotting --------------------------------------------------------------------
# Margins of panels (the function subplot() evenly space the panles; here I use 
# mar() to separate the rightmots panle from the two on the left)
mar1 <- c(0, 2, 0, 0)
mar2 <- c(0, 0, 0, 2)
mar3 <- mar1
xmar = 0.1
ymar = 0.1

j <- 0.03  # jitter if CIs
ylim = c(-65, 5)
nr = 4
nc = 3

# Add panels -------------------------------------------------------------------
# Row 1 from top
id <- 3
rr <- 1
idplot(id = id, rr = rr)

# Row 2 from top 
id <- 9
rr <- 2
idplot(id = id, rr = rr, legend = TRUE)

# Row 3 from top 
id <- 11
rr <- 3
idplot(id = id, rr = rr)

# Row 4 from top 
id <- 12
rr <- 4
idplot(id = id, rr = rr, xlabels = TRUE)
# ------------------------------------------------------------------------------

# Add axis text ----------------------------------------------------------------
# Note: text() easier to work with than mtext (still, trial and error needed to 
# find coordinates)
cex = 0.75
par(fig = c(0, 1, 0, 1), mar = c(0, 0, 0, 0), oma = c(0, 0, 0, 0), new = TRUE)

# Empty plot 0-100, so you can guess the coordinates for text() 
plot(0:100, 0:100, pch = '', xlab = '', ylab = '', axes = FALSE) 

text(x =  5, y = 50, "Threshold [dB]", cex = cex, pos = 1, srt = 90)
text(x = 70, y = 50, "Threshold difference (laterlization - detection), [dB]", cex = cex, pos = 1, srt = 90)
text(x = 55, y =  4, "Inter-click interval, ICI [ms]", cex = cex, pos = 1, srt = 0)

# Add text to upper row panels
text(x = 30, y = 103.2, "Pre-training\nthresholds", cex = 0.6, pos = 1, srt = 0, font = 3)
text(x = 56, y = 103.2, "Post-training\nthresholds", cex = 0.6, pos = 1, srt = 0, font = 3)
text(x = 92, y = 103.2, "Threshold differences:\nLateralization - Detection", cex = 0.6, pos = 1, srt = 0, font = 3)

# Add ICI = 200 ms, middle panel
arrows(x0 = 62.3,      x1 = 62.3, y0 = 38.5, y1 = 42.5, length = 0.05, angle = 30, code = 1,
       lwd = 0.5)
text("ICI = 200 ms", x = 62.6,      y = 44.8, cex = 0.5, pos = 3, srt = 90)

# Add ICI = 200 ms, rightmost panel
xx <- 102
arrows(x0 = xx,      x1 = xx, y0 = 36.5, y1 = 40.5, length = 0.05, angle = 30, code = 1,
       lwd = 0.5)
text("ICI = 200 ms", x = xx+0.3,      y = 43, cex = 0.5, pos = 3, srt = 90)
# ------------------------------------------------------------------------------
## -----------------------------------------------------------------------------


## Close pdf or png ------------------------------------------------------------
if(savefig > 0){
  graphics.off() 
}
## -----------------------------------------------------------------------------

