# ALEXIS 120. Stimulus figures, one fordetection and one for laterlization. 
# The script import the echo click used in the experiment: E1.wav
# This is a revised version of figure, after reviewer comments (JASA Reviewer 2)
# 
# MN 2020-10-02; 2021-01-04

## Load stuff ------------------------------------------------------------------
library(tuneR)  # readWave()
## -----------------------------------------------------------------------------


## Clear everything ------------------------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
## -----------------------------------------------------------------------------


## Load stuff ------------------------------------------------------------------
source("analys/2_a120_set_variables.R")  # This also load functions
## -----------------------------------------------------------------------------


## Get signal from wav-file ----------------------------------------------------
sdata <- readWave("./rawdata/E1.wav")  # Sound object: str(sdata) to see content
s <- sdata@left  # Signal
s <- s/max(abs(s)) # Normalize
fs <- sdata@samp.rate
t <- seq(1/fs, length(s)/fs, by = 1/fs) * 1000  # Time vector ms
## -----------------------------------------------------------------------------


## Plotting functions ----------------------------------------------------------
leadlag <- function(s, ici = 24, llr = -10, before = 96, after = 0, leadonly = FALSE){
  # Creates data frame with left and right channel of leadlag combination
  zstart <- rep(0, before)
  zend <- rep(0, after)
  zici <- rep(0, ici * 48)
  zitd <- rep(0, 0.25 * 48)
  
  if (leadonly) {nolag = 0} else {nolag = 1}
  
  # Left channel (favored, revert output to change)
  lead_left <- c(zstart, s, zend, zici, zitd)
  lag_left <-  c(zstart, zici, s, zend, zitd) * (10**(llr/20.0)) * nolag
  left <- lead_left + lag_left
   
  # Right channel (disfavored, ILD = 6 dB; ITD = 0.25 ms, revert output to change)
  lead_right <- c(zstart, s, zend, zici, zitd)
  lag_right <- c(zstart, zici, zitd, s, zend) * (10**(llr/20.0)) *(10**(-6/20.0)) * nolag
  right <- lead_right + lag_right
  
  out <- data.frame(left, right)
  out 
}

plot_isi <- function(s){
  ss <- leadlag(s, ici = 24, leadonly = TRUE, llr = -10)  # Just to get nrow(ss)

  t <- seq(1/fs, nrow(ss)/fs, by = 1/fs)
  left <- 0 * ss$left + 2
  right <- 0 * ss$right
  xlim <- c(0, max(t))  
  ylim = c(-1.1, 3)
  plot(t, left, xlim = xlim, ylim = ylim, pch = '', xlab = '', ylab = '', axes = FALSE)
  lines(t, left, lwd = 0.5)
  lines(t, right, lwd = 0.5)
  axis(1, tck = 0.0, pos = ylim[1], cex.axis = 0.5, at = c(), labels = FALSE, lwd = 0.5)

}


plot_interval <- function(s, ici = 24, llr = -10, left_favored = TRUE, leadonly = FALSE,
                          yaxis = TRUE){
  # Plot one interval (a trial consisted of two intervals)
  ss <- leadlag(s, ici = ici, leadonly = leadonly, llr = llr)
  
  if (left_favored) {
    left <- ss$left + 2
    right <- ss$right
  } else {
    left <- ss$right + 2  # REvert channels if right is favord
    right <- ss$left
  }

  
  t <- seq(1/fs, nrow(ss)/fs, by = 1/fs) * 1000 - (96/48)  # 100 from before argument in leadlag()
  xlim <- c(-(96/48), max(t))  # -100 from before argument in leadlag()
  ylim = c(-1.1, 3)
  plot(t, left, xlim = xlim, ylim = ylim, pch = '', xlab = '', ylab = '', axes = FALSE)
  lines(t, left, lwd = 0.5)
  lines(t, right, lwd = 0.5)
  
  axis(1, tck = 0.01, pos = ylim[1], cex.axis = 0.4, mgp = c(3, -0.2, 0),
       at = c(-(96/48), seq(0, 40, by = 10)), labels = c('', seq(0, 30, by = 10),''), lwd = 0.5)
  if (yaxis) {
    axis(2, tck = 0.01, pos = xlim[1], cex.axis = 0.4, mgp = c(3, -0.2, 0), 
         at = c(ylim[1], ylim[2]), labels = FALSE, las = 2, lwd = 0.5)
  }

}
## -----------------------------------------------------------------------------

## Plot ------------------------------------------------------------------------
# Define saving option for plot ------------------------------------------------
savefig = figsave  # 0 = dont save, show in Rstudio, 1 = pdf, 2 = png

# Open pdf (paper = 'letter' or 'A4' to get fig on full page)
if(savefig == 1) {
  pdf("./manus/fig1.pdf", width = 15/2.54, height = 10/2.54, paper = 'letter')
}

# Open png 
if(savefig == 2) {
  png("./manus/fig1.png", units = "in", res = 600, width = 15/2.54, height = 10/2.54)
}
# ------------------------------------------------------------------------------


# Fix default settings ---------------------------------------------------------
par(mar = c(0.2, 0, 3.5, 4), lwd = 0.5)  # fix margins to move subplots closer
xmar = 0.05
ymar = 0.05
# ------------------------------------------------------------------------------

plot.new()

mtext(side = 3, cex = 0.6, line = 0, "Detection", font = 2)
mtext(side = 3, cex = 0.6, line = -9, "Lateralization", font = 2)

# Upper row: Detection, LLR = -10 ----------------------------------------------
llr = -10
par(fig = subplot(rr = 1, cc = 1, nr = 2, nc = 2, xmar = xmar, ymar = ymar), new = TRUE)
plot_interval(s,llr = llr, left_favored = TRUE, yaxis = TRUE)
text(7, 2.8, '1st interval', cex = 0.6, font = 3)
mtext(side = 2, cex = 0.6, "Amplitude [arbitrary unit]")

par(fig = subplot(rr = 1, cc = 2, nr = 2, nc = 2, xmar = xmar, ymar = ymar), new = TRUE)
plot_interval(s,llr = llr, left_favored = FALSE, yaxis = FALSE, leadonly = TRUE)
text(7, 2.8, '2nd interval', cex = 0.6, font = 3)

# ------------------------------------------------------------------------------

# Lower row: Laterlization, LLR = -10 ------------------------------------------
llr = -10
par(fig = subplot(rr = 2, cc = 1, nr = 2, nc = 2, xmar = xmar, ymar = ymar), new = TRUE)
plot_interval(s,llr = llr, left_favored = TRUE, yaxis = TRUE)
text(7, 2.4, 'Left ear', cex = 0.6, font = 3)
text(7, 0.3, 'Right ear', cex = 0.6, font = 3)
mtext(side = 1, cex = 0.6, 'Time [ms]', line = 0.2)
mtext(side = 2, cex = 0.6, "Amplitude [arbitrary unit]")

par(fig = subplot(rr = 2, cc = 2, nr = 2, nc = 2, xmar = xmar, ymar = ymar), new = TRUE)
plot_interval(s,llr = llr, left_favored = FALSE, yaxis = FALSE)
mtext(side = 1, cex = 0.6, 'Time [ms]', line = 0.2)
# ------------------------------------------------------------------------------


# ------------------------------------------------------------------------------

# Close pdf or png ------------------------------------------------------------
if(savefig > 0){
  graphics.off() 
}
# -----------------------------------------------------------------------------
## -----------------------------------------------------------------------------

