# ALEXIS 120. Figure training: result from day 1 to 30 (post-data in separate figure)
# This is a revised version of figure, after reviewer comments (JASA Reviewer 2)
# MN 2020-01-24; 2020-12-22


## Clear everything ------------------------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
## -----------------------------------------------------------------------------


## Load stuff ------------------------------------------------------------------
library(HDInterval) # hdi()

# Load user/made functions
source("analys/1_a120_functions.R") 
source("analys/2_a120_set_variables.R") 
 

# Load MCMC training
load("analys/mcmc_train.RData")

# Load MCMC pre-test = main experiment and pos-post
load("analys/mcmc_main.RData")
load("analys/mcmc_post.RData")
## -----------------------------------------------------------------------------

## Function for finding post-training th. th(id) gives pretest th
thpost <- function(id) {
  # Load global variable with samples from individual posterior
  fname <- ls(envir=.GlobalEnv, pattern = paste('postdraws_id', id, sep = ''))
  print(fname)  # Just as a check
  draws <- get(fname)
  
  # Threshold: parameter m
  th <- apply(draws$m, 2, median)
  thci <- apply(draws$m, 2, hdi)
  out <- rbind(th, thci)
  colnames(out) <- c('det6', 'det8.5', 'det12', 'det17', 'det24', 'det34', 'det48', 'det200',
                     'lat6', 'lat8.5', 'lat12', 'lat17', 'lat24', 'lat34', 'lat48', 'lat200')
  sstat <- c('mdn', 'hdpi95lo', 'hdpi95hi')
  ss <- rep(id, nrow(out))
  out <- data.frame(id = ss, stat = sstat, out)
  rownames(out) <- c()  # Get rid of row names
  out # Output is a data frame
}

## -----------------------------------------------------------------------------


## Function for plotting training data -----------------------------------------

get_data <- function(iddata, ici) {
  gg <- iddata[, grep(as.character(ici), names(iddata), value = TRUE)]
  day <- 1:nrow(gg)
  gg <- cbind(day, gg)
  gg
}


empty_train <- function(xlabels = FALSE, ylabels = FALSE, ymax = 0, yrange = 21,
                        axislwd = 0.4, cex.axis = 0.5) {
  # Make exmpty plot
  xlim <- c(-2.5, 31.5) # Days.  old: c(-1, 30) 
  ylim <- c(-65, 5) # Old: c(ymax + 1 - yrange, ymax + 1); yrange not used
  plot(1:29, pch = '', xlim = xlim, ylim = ylim, axes = FALSE,
       xlab = '', ylab = '')
  
  # Add grid lines
  lines(x = c(1, 1), y = ylim, lwd = 0.5, lty = 1, col = 'grey')
  lines(x = c(7, 7), y = ylim, lwd = 0.5, lty = 1, col = 'grey')
  lines(x = c(14, 14), y = ylim, lwd = 0.5, lty = 1, col = 'grey')
  lines(x = c(21, 21), y = ylim, lwd = 0.5, lty = 1, col = 'grey')
  lines(x = c(28, 28), y = ylim, lwd = 0.5, lty = 1, col = 'grey')

  
  # Add x-axis
  xat <-  c(xlim[1], 1:28, xlim[2])
  xlabs <- c('', '1-', rep('', 5), '7-', rep('', 6), '14-', rep('', 6), '21-', rep('', 6), '28-', '')
  if (!xlabels ) {xlabs = FALSE}
  
  axis(1, at = xat, labels = xlabs, 
       tck = 0.01, pos = ylim[1], cex.axis = cex.axis, mgp = c(3, 0, 0),
       lwd = axislwd, las = 1)
  axis(3, at = xat, labels = FALSE, 
       tck = 0.01, pos = ylim[2], lwd = axislwd)
  
  # Add y-axis
  # old: yat <-  c(ylim[1], seq(ceiling(ylim[1]), floor(ylim[2]), by = 3), ylim[2])
  # old: ylabs <- c('', seq(ceiling(ylim[1]), floor(ylim[2]), by = 3), '')
  ylabs <- c('', seq(ylim[1]+5, ylim[2]-5, by = 10), '')
  yat <- c(ylim[1], seq(ylim[1]+5, ylim[2]-5, by = 10), ylim[2])
  if (!ylabels ) {ylabs = FALSE}
  
  
  axis(2, at = yat, 
       labels = ylabs,
       las = 2, tck = 0.01, pos = xlim[1], cex.axis = cex.axis, mgp = c(3, 0.2, 0),
       lwd = axislwd)
  axis(4, at = yat, labels = FALSE,
       las = 2, tck = 0.01, pos = xlim[2], lwd = axislwd)
}


add_training <- function(data_id_ici, pointcex = 0.4, linelwd = 0.4) {
  gg <- data_id_ici  # Data frame with data from specified id and ici
  lines(gg[, 1], gg[, 2], lty = 1, lwd = linelwd)
  
  # 95 CIs
  arrows(x0 = gg[, 1], x1 = gg[, 1], y0 = gg[, 3], y1 = gg[, 4], code = 3,
         length = 0, lwd = linelwd, col = 'black')
  
  # Point estimates
  points(gg[, 1], gg[, 2], pch = 22, bg = 'white', cex = pointcex, lwd = linelwd)
}


panel_idici <- function(iddata, ici, xlabels = FALSE, ylabels = FALSE, yrange = 18) {
  dd <- get_data(iddata, ici)
  ymax <- max(dd[, 2]) + 9  # + 9 added in revised figure to fit pre-test data
  empty_train(xlabels = xlabels, ylabels = ylabels, ymax = ymax, yrange = yrange)
  add_training(dd)
}

# function that adds data from pr and post test (as suggested by JASA reviewer 2)
add_prepost <- function(id, ici) {
  id <- 120000 + id
  
  # Find data
  cols <- c(paste("det", as.character(ici), sep = ""), paste("lat", as.character(ici), sep = ""))
  pre <- th(id)[1, cols]
  prelo <- th(id)[2, cols]
  prehi <- th(id)[3, cols]
  post <- thpost(id)[1, cols]
  postlo <- thpost(id)[2, cols]
  posthi <- thpost(id)[3, cols]
  
  # Add pre-test data -----
  # Detection
  j <- 0.4
  arrows(x0 = -1-j, x1 = -1-j, y0 = prelo[,1], y1 = prehi[,1], code = 3,
         length = 0, lwd = 0.4, col = 'black')
  points(-1, pre[1], pch = 21, bg = "grey", cex = 0.4, lwd = 0.4) 
  # Lateralization
  arrows(x0 = -1+j, x1 = -1+j, y0 = prelo[,2], y1 = prehi[,2], code = 3,
         length = 0, lwd = 0.4, col = 'black')
  points(-1, pre[2], pch = 22, bg = "white", cex = 0.4, lwd = 0.4)  
  
  # Add post-test data -----
  # Detection
  arrows(x0 = 30-j, x1 = 30-j, y0 = postlo[,1], y1 = posthi[,1], code = 3,
         length = 0, lwd = 0.4, col = 'black')
  points(30, post[1], pch = 21, bg = "grey", cex = 0.4, lwd = 0.4)
  # Lateralization
  arrows(x0 = 30+j, x1 = 30+j, y0 = postlo[,2], y1 = posthi[,2], code = 3,
         length = 0, lwd = 0.4, col = 'black')
  points(30, post[2], pch = 22, bg = "white", cex = 0.4, lwd = 0.4)  
  
}

## Define saving option for plot -----------------------------------------------
savefig = figsave # 0 = dont save, show in Rstudio, 1 = pdf, 2 = png

# Open pdf (paper = 'letter' or 'A4' to get fig on full page)
if(savefig == 1) {
  pdf("./manus/fig4.pdf", width = 15/2.54, height = 20/2.54, paper = 'letter')
}

# Open png 
if(savefig == 2) {
  png("./manus/fig4.png", units = "in", res = 600, width = 15/2.54, height = 16/2.54)
}
## -----------------------------------------------------------------------------

## Plotting --------------------------------------------------------------------
nr = 4
nc = 5
yrange = 24 # This arg not used in revised figure with fixed ylim = c(-5, -65)
par(mar = c(0, 1, 0, 0), oma = c(0, 0, 0, 0)) 
idcex <- 0.55

# Row 1 from top (id = 3) ------------------------------------------------------
iddata <- train03
id <- 3

iciat = 18
iciline = -1.2
icicex = 0.5
par(fig = subplot(rr = 1, cc = 1, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1))
panel_idici(iddata = iddata, ici = 6, ylabels = TRUE, yrange = yrange)
mtext("ICI = 6 ms", side = 3, line = iciline, cex = icicex, at = iciat)
text(x = 3.2, y = -60, labels = "ID 3", cex = idcex, font = 3)
add_prepost(id = id, ici = 6)

par(fig = subplot(rr = 1, cc = 2, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 12, ylabels = TRUE, yrange = yrange)
mtext("ICI = 12 ms", side = 3, line = iciline, cex = icicex, at = iciat, pos = 4)
add_prepost(id = id, ici = 12)
            
par(fig = subplot(rr = 1, cc = 3, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 24, ylabels = TRUE, yrange = yrange)
mtext("ICI = 24 ms", side = 3, line = iciline, cex = icicex, at = iciat)
add_prepost(id = id, ici = 24)

par(fig = subplot(rr = 1, cc = 4, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 48, ylabels = TRUE, yrange = yrange)
mtext("ICI = 48 ms", side = 3, line = iciline, cex = icicex, at = iciat)
add_prepost(id = id, ici = 48)

par(fig = subplot(rr = 1, cc = 5, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 200, ylabels = TRUE, yrange = yrange)
mtext("ICI = 200 ms", side = 3, line = iciline, cex = icicex, at = iciat)
add_prepost(id = id, ici = 200)
# ------------------------------------------------------------------------------


# Row 2 from top (id = 9) -----------------------------------------------------------
iddata <- train09
id <- 9
par(fig = subplot(rr = 2, cc = 1, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 6, ylabels = TRUE, yrange = yrange)
text(x = 3.2, y = -60, labels = "ID 9", cex = idcex, font = 3)
add_prepost(id = id, ici = 6)

par(fig = subplot(rr = 2, cc = 2, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 12, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 12)

par(fig = subplot(rr = 2, cc = 3, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 24, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 24)

par(fig = subplot(rr = 2, cc = 4, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 48, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 48)

par(fig = subplot(rr = 2, cc = 5, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 200, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 200)
# ------------------------------------------------------------------------------


# Row 3 from top (id = 11) ------------------------------------------------------
iddata <- train11
id <- 11
par(fig = subplot(rr = 3, cc = 1, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 6, ylabels = TRUE, yrange = yrange)
text(x = 3.2, y = -60, labels = "ID 11", cex = idcex, font = 3)
add_prepost(id = id, ici = 6)

par(fig = subplot(rr = 3, cc = 2, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 12, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 12)

par(fig = subplot(rr = 3, cc = 3, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 24, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 24)

par(fig = subplot(rr = 3, cc = 4, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 48, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 48
            )
par(fig = subplot(rr = 3, cc = 5, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 200, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 200)
# ------------------------------------------------------------------------------


# Row 4 from top (id = 12) ------------------------------------------------------
iddata <- train12
id <- 12
par(fig = subplot(rr = 4, cc = 1, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 6, ylabels = TRUE, yrange = yrange)
text(x = 3.2, y = -60, labels = "ID 12", cex = idcex, font = 3)
add_prepost(id = id, ici = 6)

par(fig = subplot(rr = 4, cc = 2, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 12, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 12)

par(fig = subplot(rr = 4, cc = 3, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 24, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 24)

par(fig = subplot(rr = 4, cc = 4, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 48, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 48)

par(fig = subplot(rr = 4, cc = 5, nr = nr, nc = nc, xmar = 0.1, ymar = 0.1), new = TRUE)
panel_idici(iddata = iddata, ici = 200, ylabels = TRUE, yrange = yrange)
add_prepost(id = id, ici = 200)

# Text for x-values
text(x = c(1, 7, 14, 21, 28), y = rep(-10, 5), 
     labels = c("Day 1 - 3", "Day 7 - 9", "Day 14-16", "Day 21-23", "Day 28-30"), 
     cex = 0.5, pos = 3, srt = 90, font = 3)

# Add arrows for pre-test and post-test
arrows(x0 = -1, x1 = -1, y0 = -41.0, y1 = -44.3, length = 0.03, angle = 30, code = 2,
       lwd = 0.5)
text("Pre-test", x = -0.15, y = -38, cex = 0.45, pos = 3, srt = 90, font = 3)

arrows(x0 = 30, x1 = 30, y0 = -45.5, y1 = -49, length = 0.03, angle = 30, code = 2,
       lwd = 0.5)
text("Post-test", x = 30.6, y = -42, cex = 0.45, pos = 3, srt = 90, font = 3)

# Add legend for symbols
points(2.5, -60, pch = 22, bg = "white", cex = 0.5, lwd = 0.4)
text("Lateralization", x = 0,  y = -60, cex = 0.5, pos = 4)

points(2.5, -63, pch = 21, bg = "grey", cex = 0.5, lwd = 0.4)
text("Detection", x = 0,  y = -63, cex = 0.5, pos = 4)
# ------------------------------------------------------------------------------


# Add axis texts (Some trial and error to get right values of argument line)
cex = 0.75
par(fig = c(0, 1, 0, 1), new = TRUE)
# Empty plot 0-100, so you know the scale of mtext()-argument at 
plot(0:100, 0:100, pch = '', xlab = '', ylab = '', axes = FALSE) 

text(x =  1, y = 55, "Threshold [dB]", cex = cex, pos = 1, srt = 90)
text(x = 55, y =  7, "Days of training (days 1-3, 2-4, ..., 28-30)", cex = cex, pos = 1, srt = 0)

# Add lines next to axis text (a lot of trial end error needed to get it right)
#lines(c(10, 35), c(0.5, 0.5))
#lines(c(75, 99), c(0.5, 0.5))
## -----------------------------------------------------------------------------


## Close pdf or png ------------------------------------------------------------
if(savefig > 0){
  graphics.off() 
}
## -----------------------------------------------------------------------------
