# Alexis 120. 
# Calculations for Table 1: Results of conttol experiment
#
# MN 2020-10-01


## Clear everything ------------------------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
## ----------------------------------------------------------------------------


## Loadstuff -------------------------------------------------------------------
source("analys/1_a120_functions.R") 
source("analys/2_a120_set_variables.R") 

# Load MCMC data control experiment
load("analys/mcmc_control.RData")
load("analys/mcmc_main.RData")
## -----------------------------------------------------------------------------


## Compile data from both main experiment and extra experiment -----------------
getth <- function(id) {
  
  # Feedback experiment
  # Load global variable with samples from individual posterior
  fname <- ls(envir=.GlobalEnv, pattern = paste('controldraws_id', id, sep = ''))
  print(fname)  # Just as a check
  draws <- get(fname)
  
  thdet <- median(draws$m1)
  cidet <- hdi(as.numeric(draws$m1), prob = 0.95)
  thlat <- median(draws$m2)
  cilat <- hdi(as.numeric(draws$m2), prob = 0.95)
  thdiff <- median(draws$m1-draws$m2)
  cidiff <- hdi(as.numeric(draws$m1)-as.numeric(draws$m2), prob = 0.95)

  feedb <- c(id, thdet, cidet, thlat, cilat, thdiff, cidiff)
  names(feedb) <- c('id', 'thdet', 'cidetlo', 'cidethi', 'thlat', 'cilatlo', 'cilathi', 'thdiff', 'cidifflo', 'cidiffhi')
  
  # Main experiment
  # Load global variable with samples from individual posterior
  fname <- ls(envir=.GlobalEnv, pattern = paste('maindraws_id', id, sep = ''))
  print(fname)  # Just as a check
  draws <- get(fname)
  
  thdet <- median(draws$m[, 5])
  cidet <- hdi(as.numeric(draws$m[, 5]), prob = 0.95)
  thlat <- median(draws$m[, 13])
  cilat <- hdi(as.numeric(draws$m[, 13]), prob = 0.95)
  thdiff <- median(draws$m[, 5] - draws$m[, 13])
  cidiff <- hdi(as.numeric(draws$m[, 5]) - as.numeric(draws$m[, 13]), prob = 0.95)
  
  mainexp <- c(id, thdet, cidet, thlat, cilat, thdiff, cidiff)
  names(mainexp) <- c('id', 'thdet', 'cidetlo', 'cidethi', 'thlat', 'cilatlo', 'cilathi', 'thdiff', 'cidifflo', 'cidiffhi')

  out <- rbind(mainexp, feedb)
  out
}

# Find id numbers from variable names
ids <- ls(envir=.GlobalEnv, pattern = paste('controldraws_id', sep = ''))
ids <- as.numeric(gsub("controldraws_id", "", ids))

# Compile data in matrix
a <- getth(ids[1])
for(j in 2:length(ids)){
  a <- rbind(a, getth(ids[j]))
}

tabledata <- round(a)
tabledata

# Save tab delimuted data, can e.g., be pasted into a spread cheet program and 
# then into a table created by a word processor
write.table(tabledata, "./analys/tabel1data.txt", sep= "\t")
